"""
Module:
    unicon.plugins.nxos

Authors:
    ATS TEAM (ats-dev@cisco.com, CSG( STEP) - India)

Description:
    This subpackage implements NXOS
"""
from .bases import BaseNxosDualRpConnection
from .bases import BaseNxosSingleRpConnection

from .connection_provider import NxosSingleRpConnectionProvider
from .connection_provider import NxosDualRpConnectionProvider

from .statemachine import NxosDualRpStateMachine

from .statemachine import NxosSingleRpStateMachine
from .setting import NxosSettings

from unicon.plugins.generic import ServiceList, HAServiceList
from unicon.plugins.nxos import service_implementation as svc


class NxosServiceList(ServiceList):
    def __init__(self):
        super().__init__()
        self.reload = svc.Reload
        self.ping6 = svc.Ping6
        self.shellexec = svc.ShellExec
        self.list_vdc = svc.ListVdc
        self.switchto = svc.SwitchVdc
        self.switchback = svc.SwitchbackVdc
        self.create_vdc = svc.CreateVdc
        self.delete_vdc = svc.DeleteVdc

class HANxosServiceList(HAServiceList):
    def __init__(self):
        super().__init__()
        self.get_rp_state = svc.GetRPState
        self.get_mode = svc.GetMode
        self.reload = svc.HANxosReloadService
        self.switchover = svc.NxosSwitchoverService
        self.reset_standby_rp = svc.ResetStandbyRP
        self.shellexec = svc.HAShellExec
        self.list_vdc = svc.ListVdc
        self.switchto = svc.SwitchVdc
        self.switchback = svc.SwitchbackVdc
        self.create_vdc = svc.CreateVdc
        self.delete_vdc = svc.DeleteVdc


class NxosSingleRpConnection(BaseNxosSingleRpConnection):
    os = 'nxos'
    series = None
    chassis_type = 'single_rp'
    state_machine_class = NxosSingleRpStateMachine
    connection_provider_class = NxosSingleRpConnectionProvider
    subcommand_list = NxosServiceList
    settings = NxosSettings()


class NxosDualRPConnection(BaseNxosDualRpConnection):
    os = 'nxos'
    series = None
    chassis_type = 'dual_rp'
    state_machine_class = NxosDualRpStateMachine
    connection_provider_class = NxosDualRpConnectionProvider
    subcommand_list = HANxosServiceList
    #subcommand_list = HAServiceList
    settings = NxosSettings()
